Plugin reference
================

:mod:`BmpImagePlugin` Module
----------------------------

.. automodule:: PIL.BmpImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`BufrStubImagePlugin` Module
---------------------------------

.. automodule:: PIL.BufrStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`CurImagePlugin` Module
----------------------------

.. automodule:: PIL.CurImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`DcxImagePlugin` Module
----------------------------

.. automodule:: PIL.DcxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`EpsImagePlugin` Module
----------------------------

.. automodule:: PIL.EpsImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FitsStubImagePlugin` Module
---------------------------------

.. automodule:: PIL.FitsStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FliImagePlugin` Module
----------------------------

.. automodule:: PIL.FliImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FpxImagePlugin` Module
----------------------------

.. automodule:: PIL.FpxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GbrImagePlugin` Module
----------------------------

.. automodule:: PIL.GbrImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GifImagePlugin` Module
----------------------------

.. automodule:: PIL.GifImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`GribStubImagePlugin` Module
---------------------------------

.. automodule:: PIL.GribStubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Hdf5StubImagePlugin` Module
---------------------------------

.. automodule:: PIL.Hdf5StubImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`IcnsImagePlugin` Module
-----------------------------

.. automodule:: PIL.IcnsImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`IcoImagePlugin` Module
----------------------------

.. automodule:: PIL.IcoImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ImImagePlugin` Module
---------------------------

.. automodule:: PIL.ImImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ImtImagePlugin` Module
----------------------------

.. automodule:: PIL.ImtImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`IptcImagePlugin` Module
-----------------------------

.. automodule:: PIL.IptcImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`JpegImagePlugin` Module
-----------------------------

.. automodule:: PIL.JpegImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Jpeg2KImagePlugin` Module
-------------------------------

.. automodule:: PIL.Jpeg2KImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`McIdasImagePlugin` Module
-------------------------------

.. automodule:: PIL.McIdasImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`MicImagePlugin` Module
----------------------------

.. automodule:: PIL.MicImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`MpegImagePlugin` Module
-----------------------------

.. automodule:: PIL.MpegImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`MspImagePlugin` Module
----------------------------

.. automodule:: PIL.MspImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PalmImagePlugin` Module
-----------------------------

.. automodule:: PIL.PalmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PcdImagePlugin` Module
----------------------------

.. automodule:: PIL.PcdImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PcxImagePlugin` Module
----------------------------

.. automodule:: PIL.PcxImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PdfImagePlugin` Module
----------------------------

.. automodule:: PIL.PdfImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PixarImagePlugin` Module
------------------------------

.. automodule:: PIL.PixarImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PngImagePlugin` Module
----------------------------

.. automodule:: PIL.PngImagePlugin
    :members: ChunkStream, PngImageFile, PngStream, getchunks, is_cid, putchunk
    :show-inheritance:
.. autoclass:: PIL.PngImagePlugin.ChunkStream
    :members:
    :undoc-members:
    :show-inheritance:
.. autoclass:: PIL.PngImagePlugin.PngImageFile
    :members:
    :undoc-members:
    :show-inheritance:
.. autoclass:: PIL.PngImagePlugin.PngStream
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`PpmImagePlugin` Module
----------------------------

.. automodule:: PIL.PpmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`PsdImagePlugin` Module
----------------------------

.. automodule:: PIL.PsdImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`SgiImagePlugin` Module
----------------------------

.. automodule:: PIL.SgiImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`SpiderImagePlugin` Module
-------------------------------

.. automodule:: PIL.SpiderImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`SunImagePlugin` Module
----------------------------

.. automodule:: PIL.SunImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`TgaImagePlugin` Module
----------------------------

.. automodule:: PIL.TgaImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`TiffImagePlugin` Module
-----------------------------

.. automodule:: PIL.TiffImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`WebPImagePlugin` Module
-----------------------------

.. automodule:: PIL.WebPImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`WmfImagePlugin` Module
----------------------------

.. automodule:: PIL.WmfImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XVThumbImagePlugin` Module
--------------------------------

.. automodule:: PIL.XVThumbImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XbmImagePlugin` Module
----------------------------

.. automodule:: PIL.XbmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XpmImagePlugin` Module
----------------------------

.. automodule:: PIL.XpmImagePlugin
    :members:
    :undoc-members:
    :show-inheritance:
